%define tarname apache-couchdb
%define couchdb_user couchdb
%define couchdb_group couchdb
%define couchdb_home %{_localstatedir}/lib/couchdb

Name:		couchdb
Version:	1.2.1
Release:	%mkrel 3
Summary:	A document database server, accessible via a RESTful JSON API
Group:		Databases
License:	Apache License
URL:		http://couchdb.apache.org/
Source0:	http://www.apache.org/dist/%{name}/releases/%{version}/%{tarname}-%{version}.tar.gz
Source1:	%{name}.service
Source2:	%{name}.tmpfiles.conf

BuildRequires:	erlang-devel erlang-compiler erlang-crypto erlang-eunit
BuildRequires:	libicu-devel 
BuildRequires:	js-devel 
BuildRequires:	help2man
BuildRequires:	curl-devel

Requires:	couchdb-bin

Requires(pre):	shadow-utils

%description
Apache CouchDB is a distributed, fault-tolerant and schema-free 
document-oriented database accessible via a RESTful HTTP/JSON API. 
Among other features, it provides robust, incremental replication 
with bi-directional conflict detection and resolution, and is 
queryable and indexable using a table-oriented view engine with 
JavaScript acting as the default view definition language.

This package contains the systemd unit needed to start a systemwide
instance of CouchDB.

%package	bin
Group:		Databases
Summary:	Binary for Couchdb, a document database server

Requires:	erlang 
Requires:	erlang-crypto
Requires:	erlang-ssl
Requires:	erlang-xmerl
Requires:	erlang-inets
Requires:	erlang-tools
Requires:	erlang-public_key
Requires:	erlang-os_mon
Requires(post): systemd >= %{systemd_required_version}

%description bin
Apache CouchDB is a distributed, fault-tolerant and schema-free 
document-oriented database accessible via a RESTful HTTP/JSON API. 
Among other features, it provides robust, incremental replication 
with bi-directional conflict detection and resolution, and is 
queryable and indexable using a table-oriented view engine with 
JavaScript acting as the default view definition language.

This package contains the binary needed to run a CouchDB instance.


%prep
%setup -q -n %{tarname}-%{version}

# fix build with new automake 1.13
sed -i -e 's,AM_CONFIG_HEADER,AC_CONFIG_HEADERS,g' configure.*

%build
autoreconf -fi
%configure2_5x \
    --with-js-include=%{_includedir}/js \
    --with-erlang=%{_libdir}/erlang%{_includedir}

%make 


%install
%makeinstall_std

# Libdir for systemd unit
sed -i -e 's|@LIBDIR@|%{_libdir}|' %{SOURCE1}

# Install systemd unit
install -D -m 755 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service

# Install tmpfiles entry
install -D -m 644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# Create /var/log/couchdb
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}

# Create /var/lib/couchdb
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}

# Create /etc/couchdb/default.d
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/default.d

# Create /etc/couchdb/local.d
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/local.d

## Use /etc/sysconfig instead of /etc/default
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mv %{buildroot}%{_sysconfdir}/default/couchdb \
%{buildroot}%{_sysconfdir}/sysconfig/%{name}
rm -rf %{buildroot}%{_sysconfdir}/default

# Remove unecessary files
rm %{buildroot}%{_sysconfdir}/rc.d/couchdb
rm -rf  %{buildroot}%{_datadir}/doc/couchdb

# clean-up .la archives
find %{buildroot} -name '*.la' -delete


%pre bin
%_pre_useradd %{couchdb_user}  %{couchdb_home} /bin/bash 


%post
%_post_service %{name}

%post bin
# (cg) NB This should really be before the _post_service above... but packaging
# here seems really bizare with it's split...
%_tmpfilescreate %{name}

%postun bin
%_postun_userdel %{couchdb_user}


%preun 
%_preun_service %{name}


%files
%doc AUTHORS BUGS CHANGES LICENSE NEWS NOTICE README THANKS
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_unitdir}/%{name}.service

%files bin
%{_bindir}/*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/local.d
%dir %{_sysconfdir}/%{name}/default.d
%config(noreplace) %attr(0644,%{couchdb_user},root) %{_sysconfdir}/%{name}/default.ini
%config(noreplace) %attr(0644,%{couchdb_user},root) %{_sysconfdir}/%{name}/local.ini
%{_tmpfilesdir}/%{name}.conf
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_mandir}/man1/*
%dir %attr(0755,%{couchdb_user},root) %{_localstatedir}/log/%{name}
%dir %attr(0755,%{couchdb_user},root) %{_localstatedir}/lib/%{name}


%changelog

* Sun Mar 24 2013 colin <colin> 1.2.1-3.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Thu Feb 07 2013 neoclust <neoclust> 1.2.1-2.mga3
+ Revision: 395014
- Update release to allow updates from mga2

* Tue Feb 05 2013 neoclust <neoclust> 1.2.1-1.mga3
+ Revision: 394707
- New version 1.2.1

* Fri Jan 11 2013 umeabot <umeabot> 1.2.0-7.mga3
+ Revision: 348189
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 31 2012 wally <wally> 1.2.0-6.mga3
+ Revision: 336582
- fix build with new automake 1.13

* Sun Nov 25 2012 colin <colin> 1.2.0-5.mga3
+ Revision: 321769
- Do not package tmpfiles conf in /etc
- Run systemd-tmpfiles --create on post install

* Fri Nov 09 2012 fwang <fwang> 1.2.0-4.mga3
+ Revision: 316630
- rebuild for updated icu

* Tue Nov 06 2012 fwang <fwang> 1.2.0-3.mga3
+ Revision: 314764
- rebuild for neww couchdb

* Wed Aug 01 2012 sander85 <sander85> 1.2.0-2.mga3
+ Revision: 277298
- Fix build.
- Migrate to systemd.
- Clean spec.
- Switch from make to %%make.

  + fwang <fwang>
    - new version 1.2.0

* Wed May 30 2012 fwang <fwang> 1.1.1-2.mga3
+ Revision: 249620
- rebuild for new icu

* Mon Dec 26 2011 fwang <fwang> 1.1.1-1.mga2
+ Revision: 187826
- new version 1.1.1
- rebuild for new js

  + dmorgan <dmorgan>
    - Add erlang-public_key as requires to fix a crash ( mga #2196)

* Mon Jun 20 2011 fwang <fwang> 1.1.0-1.mga2
+ Revision: 110327
- tweak br
- new version 1.1.0

* Sat Apr 16 2011 misc <misc> 1.0.2-1.mga1
+ Revision: 86162
- update to 1.0.2

* Sat Mar 26 2011 dmorgan <dmorgan> 1.0.1-2.mga1
+ Revision: 77595
- imported package couchdb


* Mon Mar 14 2011 Funda Wang <fwang@mandriva.org> 1.0.1-2mdv2011.0
+ Revision: 644571
- rebuild for new icu

* Mon Aug 23 2010 Sandro Cazzaniga <kharec@mandriva.org> 1.0.1-1mdv2011.0
+ Revision: 572075
- update to 1.0.1

* Mon Jul 26 2010 Funda Wang <fwang@mandriva.org> 1.0.0-1mdv2011.0
+ Revision: 560867
- New version 1.0.0

* Mon Apr 19 2010 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-3mdv2010.1
+ Revision: 536791
- Fix mix-up of different rpm scripts

* Sat Apr 17 2010 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-2mdv2010.1
+ Revision: 536039
- Move user creation to bin subpackage (fixes bug #58683:
  installs files as unexisting user couchdb)

* Fri Apr 16 2010 Frederik Himpe <fhimpe@mandriva.org> 0.11.0-1mdv2010.1
+ Revision: 535632
- Update to new version 0.11.0 (fixes CVE-2010-0009)
- Remove icu-config patch: no longer needed

* Wed Apr 07 2010 Michael Scherer <misc@mandriva.org> 0.10.1-5mdv2010.1
+ Revision: 532835
- place requirement on couchdb-bin subpackages

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 0.10.1-4mdv2010.1
+ Revision: 526061
- fix includedir
- rebuild for new icu

* Sun Feb 14 2010 Frederik Himpe <fhimpe@mandriva.org> 0.10.1-3mdv2010.1
+ Revision: 505918
- Some more Requires (via Debian)
- Fix Requires
- Don't depend on icu-config (Debian patch)

* Thu Feb 11 2010 Michael Scherer <misc@mandriva.org> 0.10.1-2mdv2010.1
+ Revision: 504017
- split couchdb binary in another rpm, so desktopcouch do not autostart the server

* Thu Dec 10 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.10.1-1mdv2010.1
+ Revision: 476022
- Updated to 0.10.1

* Tue Nov 10 2009 Michael Scherer <misc@mandriva.org> 0.10.0-1mdv2010.1
+ Revision: 463885
- disable parralel build, as it seems there is some trouble on klodia
- fix BuildRequires, as erlang compiler is not in erlang-devel
- import couchdb, based on Fedora specfile

